import { NativeModules, Platform } from 'react-native';

const LINKING_ERROR =
  `The package 'react-native-image-resizer' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;

const ImageResizerModule = isTurboModuleEnabled
  ? require('./NativeImageResizer').default
  : NativeModules.ImageResizer;

const ImageResizer = ImageResizerModule
  ? ImageResizerModule
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      }
    );

interface StaticOptions {
  width?: number;
  height?: number;
  outFormat?: string;
  mode?: string;
  quality?: number;
}

export function resizeStaticImagesBatch(uris:string[], userOptions: StaticOptions): Promise<void> {
  return new Promise((resolve, reject) => {
    
    if (!uris || uris.length === 0) {
      reject("Image URIs array is empty");
      return;
    }

    ImageResizer.ResizeStaticImagesBatch(uris, userOptions)
      .then((r) => {
        resolve(r);
      })
      .catch((error) => {
        reject(error);
      });
  });
}

export function resizeStaticImage(uri:string, userOptions: StaticOptions): Promise<void> {
  return new Promise((resolve, reject) => {
    
    if(typeof uri !== 'string'){
      throw new Error("You must provider uri:string of image file as 1st arguement");
    }

    ImageResizer.ResizeStaticImage(uri, userOptions)
      .then((r) => {
        resolve(r);
      })
      .catch((error) => {
        reject(error);
      });
  });
}
export function resizeAnimatedImage(uri:string, userOptions: StaticOptions): Promise<void> {
  return new Promise((resolve, reject) => {
    
    if(typeof uri !== 'string'){
      throw new Error("You must provider uri:string of image file as 1st arguement");
    }

    ImageResizer.ResizeAnimatedImage(uri, userOptions)
      .then((r) => {
        resolve(r);
      })
      .catch((error) => {
        reject(error);
      });
  });
}


export function multiply(a: number, b: number): Promise<number> {
  return ImageResizer.multiply(a, b);
}
